# SAGE file which builds covers of the orbifold B
#
# By Nathan Dunfield.   This file is in the public domain.  

import SnapPea, re

# Load the manifold B, and double check that the fundamental group
# presentation matches the one used in "constructing_M.magma"

B = SnapPea.get_manifold("Bfilled")

magma_pres =  re.search("GB := (.*);\n", open("constructing_M.magma").read()).group(1)
G = B.fundamental_group()
curr_pres = G.magma_string()
assert magma_pres == curr_pres

# Now build M

def build_M():
    magma.load("constructing_M.magma")
    M = B.create_cover( magma("MCoverPermDescription ").sage())
    for i in range( M.get_num_cusps() - 1 ):
        M.fill_cusp(0)
    M.save("Mraw")

# and N

def build_N():
    magma.load("constructing_M.magma")
    M = B.create_cover( magma("NCoverPermDescription").sage())
    for i in range( M.get_num_cusps() - 1 ):
        M.fill_cusp(0)
    M.save("Nraw")

def build_NS():
    magma.load("constructing_M.magma")
    M = B.create_cover( magma("NSCoverPermDescription").sage())
    M.save("NSraw")
